% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/coffee_pathogenicity.R
\name{coffee_pathogenicity}
\alias{coffee_pathogenicity}
\title{Meloidogyne Damage Level in Coffee}
\format{Um \code{data.frame} com 144 observações e 10 variáveis, em
     que

\describe{

\item{\code{rootstock}}{Fator categórico que indica a cultivar de
    cafeeiro plantada em vasos com 20 litros (20000 cm\eqn{3}) de
    solo contaminado com nematoide. [TODO indica se a cultivar tem
    porta-enxerto ou não?]}

\item{\code{ind}}{Initial nematode density. Controled numeric factor
    that is the the nematode density put in each pot (units
    cm\eqn{-3} of soil).}

\item{\code{atw}}{Aerial top weight (gram), total aerial part mass of
    plants 20 months after pots sowing.}

\item{\code{frw}}{Fresh root weight (gram), total root mass of plants
    20 months after pots sowing.}

\item{\code{vol}}{Volume (ml), suspensão obtida da extração dos
    nematoides raízes. Esse volume foi agitado para homogeneização e
    depois uma alíquota de 1 ml foi extraída e colocada em uma lâmina
    de contagem.}

\item{\code{count1}, \code{count2}}{Number of nematodes from a sample
    of solution (Half slide nematode counting), homogeneizada, sob
    microscópio óptico, obtida pela pesagem do sistema radicular das
    plantas após a lavagem aos 20 meses.}

\item{\code{fpop}}{Nematode final population, obtida pela soma
    das contagens 1 e 2, multiplicada pelo volume total da suspensão
    obtida da extração (\code{fpop = (count1 + count2) * vol})}

\item{\code{nemg}}{Nematodes per gram of root, obtida pela divisão da
    população final pela massa fresca de raiz. This is the number of
    nematodes (count1 plus count2) times volume divided by fresh root
    mass (\code{nemg = fpop/frw}).}

\item{\code{rf}}{Reproduction factor, obtido pela divisão da
    População final de nematoides, pela população inicial inoculada
    que é a densidade por cm\eqn{3} vezes o volume do vaso (\code{rf
    = fpop/(20000 * ind)})}

}}
\source{
TODO Indicar a propriedade ou responsáveis pelos dados para
    que as pessoas que forem usar possam pedir permissão. Se for
    pesquisa com financiamento, indicar a agência de fomento, número
    do projeto, etc.
}
\description{
Resultados de um experimento em casa de vegetação que
    estudou a relação entre o dano causado por população inicial
    crescente de Meloidogyne a cafeeiro pé franco (arábica) e
    enxertado (canefora), por meio do peso da parte aérea das
    plantas, peso do sistema radicular e a multiplicação dos
    nematoides 20 meses após a inoculação.  O solo dos vasos foi
    inicialmente contaminado com nematoides e as parcelas tiveram uma
    planta cada. Ao final do experimento as raízes das plantas foram
    lavadas, pesadas, trituradas, peneiradas e a suspensão obtida de
    cada parcela foi utilizada para fazer a contagem dos nematoides
    em aliquotas dessa suspensão.
}
\examples{

library(lattice)

data(coffee_pathogenicity)
str(coffee_pathogenicity)

xtabs(~ind + rootstock, data = coffee_pathogenicity)

xyplot(atw ~ factor(ind), groups = rootstock,
       data = coffee_pathogenicity, type = c("p", "a"))

xyplot(frw ~ factor(ind), groups = rootstock,
       data = coffee_pathogenicity, type = c("p", "a"))

xyplot(log(nemg) ~ factor(ind), groups = rootstock,
       data = coffee_pathogenicity, type = c("p", "a"))

}

